aeron_async_add_counter_cancel

Function aeron_async_add_counter_cancel 

pub unsafe extern "C" fn aeron_async_add_counter_cancel(
    client: *mut aeron_t,
    async_: *mut aeron_async_add_counter_t,
) -> c_int
Cancel an in-progress aeron_async_add_counter operation. Not applicable to aeron_async_add_static_counter, i.e. attempt to cancel static counter will fail with an error.

Will eventually free the given aeron_async_add_counter_t instance. If a counter gets created by the time cancellation happens, it will get removed.

Note: The above guarantees only apply when a call to this method succeeds, i.e. return value is zero. If a return value is non-zero the operation won't be canceled and the aeron_async_add_counter_t instance won't be freed.

@param client which the counter is being added to. @param async operation to be canceled. Must not be accessed after this call succeeds. @return 0 for success or -1 for error.